==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/experiments/dialogs_es.lua <==

dialogId("bank-m-labolator1", "font_small", "This must be some kind of laboratory.")
dialogStr("Este debe ser alguna clase de laboratorio.")


dialogId("bank-m-labolator2", "font_small", "It seems that even UFOs can be equipped with an on-board lab.")
dialogStr("Parece que incluso los OVNIs pueden ser equipados con un laboratorio a bordo.")


dialogId("bank-m-labolator3", "font_small", "This looks like a laboratory.")
dialogStr("Esto luce como un laboratorio.")


dialogId("bank-v-pokusy1", "font_big", "These experiments seem quite suspicious to me.")
dialogStr("Esos experimentos me parecen bastante sospechosos.")


dialogId("bank-v-pokusy2", "font_big", "I think that someone`s carrying out some rather suspicious experiments here.")
dialogStr("Creo que alguien está llevando a cabo unos experimentos algo sospechosos aquí.")


dialogId("bank-m-jejda", "font_small", "My gosh, what`s this?!?")
dialogStr("¿¡¿Dios mio, qué es esto?!?")


dialogId("bank-v-zije", "font_big", "Everything`s alive here.")
dialogStr("Todo está vivo aquí.")


dialogId("bank-m-nerus", "font_small", "Shhhhh, I need to examine this laboratory.")
dialogStr("Shhhh, necesito examinar este laboratorio.")


dialogId("bank-m-bojim", "font_small", "I`m little bit afraid of that thing behind the door...")
dialogStr("Me asusta un poco esa cosa detrás de la puerta...")


dialogId("bank-m-ocicka", "font_small", "Why does it have three eyes?")
dialogStr("¿Porqué tiene tres ojos?")


dialogId("bank-v-pomoc", "font_big", "Stop what you`re doing down there and come help me!")
dialogStr("¡Detén lo que estás haciendo ahí abajo y ven a ayudarme!")


dialogId("bank-m-organismy", "font_small", "I would never have thought that we`d find so many living things inside a UFO...")
dialogStr("Nunca hubiera pensado que encontraríamos tantas cosas vivas en un OVNI...")


dialogId("bank-v-potvory", "font_big", "There are an incredible number of different creatures here!")
dialogStr("¡Hay un número increíble de criaturas distintas aquí!")


dialogId("bank-v-mnozeni", "font_big", "My goodness, look at those things reproduce!")
dialogStr("Por la bondad divina, ¡Mira como se reproducen esas cosas!")


dialogId("bank-m-nesetkala", "font_small", "I`ve never seen this kind of organism before.")
dialogStr("Nunca había visto esta clase de organismo antes.")


dialogId("bank-m-kouka", "font_small", "Help! It`s looking at me!")
dialogStr("¡Ayuda! ¡Me está mirando!")


dialogId("bank-m-fuj", "font_small", "Yuck.")
dialogStr("¡Wuack!.")


dialogId("bank-m-nervozni", "font_small", "That hand gives me the creeps...")
dialogStr("Esa mano me da escalofríos...")


dialogId("bank-m-zkumavka", "font_small", "There`s a strange odor coming from this test-tube...")
dialogStr("Hay un extraño olor que sale de ese tubo de ensayo...")


dialogId("bank-m-hlavakolem", "font_small", "All of this is making my head spin...")
dialogStr("Todo esto hace que me de vueltas la cabeza...")


dialogId("bank-v-neproplavu1", "font_big", "I can`t swim through here. We`re going to have to push this aside.")
dialogStr("No puedo nadar por aquí. Vamos a tener que empujar eso a un lado.")


dialogId("bank-v-neproplavu2", "font_big", "I can`t swim through here. We`re going to have to push this down.")
dialogStr("No puedo nadar por aquí. Vamos a tener que empujar esto hacia abajo.")


dialogId("bank-v-nahazet", "font_big", "We`re going to need to throw on a lot more of these things.")
dialogStr("Vamos a tener que tirar mucho más de esas cosas.")


dialogId("bank-v-jeste", "font_big", "More.")
dialogStr("Más.")


dialogId("bank-m-prohlednout", "font_small", "We have to look everything here over very carefully.")
dialogStr("Tenemos que mirar todo lo que hay aquí muy cuidadosamente.")


dialogId("bank-v-vypad1", "font_big", "I`d rather get out of here.")
dialogStr("Preferiría irme de aquí.")


dialogId("bank-v-vypad2", "font_big", "You know, I`d really rather get out of here.")
dialogStr("Tu sabes, realmente preferiría irme de aquí.")


dialogId("bank-v-flaska", "font_big", "The odor from this bottle is making me sick.")
dialogStr("El olor de esta botella me está enfermando.")


dialogId("bank-m-rozbila", "font_small", "Ooops, it broke...")
dialogStr("Oh, se rompió...")


dialogId("bank-m-tvorove", "font_small", "I think that some of these creatures here are a result of genetic engineering.")
dialogStr("Creo que algunas de esas criaturas son el resultado de la ingeniería genética.")


dialogId("bank-m-prehnal1", "font_small", "This is just too much!")
dialogStr("¡Esto es demasiado!")


dialogId("bank-m-prehnal2", "font_small", "How morbid!")
dialogStr("¡Qué morboso!")


dialogId("bank-m-mrtvolka", "font_small", "This corpse looks familiar to me.")
dialogStr("Este cadáver me parece familiar.")

==> fillets-ng-data_1.0.1.orig.tar.gz: fillets-ng-data-1.0.1/script/experiments/dialogs_es.lua <==

dialogId("bank-m-labolator1", "font_small", "This must be some kind of laboratory.")
dialogStr("Este debe ser alguna clase de laboratorio.")


dialogId("bank-m-labolator2", "font_small", "It seems that even UFOs can be equipped with an on-board lab.")
dialogStr("Parece que incluso los OVNIs pueden ser equipados con un laboratorio a bordo.")


dialogId("bank-m-labolator3", "font_small", "This looks like a laboratory.")
dialogStr("Esto luce como un laboratorio.")


dialogId("bank-v-pokusy1", "font_big", "These experiments seem quite suspicious to me.")
dialogStr("Esos experimentos me parecen bastante sospechosos.")


dialogId("bank-v-pokusy2", "font_big", "I think that someone’s carrying out some rather suspicious experiments here.")
dialogStr("Creo que alguien está llevando a cabo unos experimentos algo sospechosos aquí.")


dialogId("bank-m-jejda", "font_small", "My gosh, what’s this?!?")
dialogStr("¿¡¿Dios mio, qué es esto?!?")


dialogId("bank-v-zije", "font_big", "Everything’s alive here.")
dialogStr("Todo está vivo aquí.")


dialogId("bank-m-nerus", "font_small", "Shhhhh, I need to examine this laboratory.")
dialogStr("Shhhh, necesito examinar este laboratorio.")


dialogId("bank-m-bojim", "font_small", "I’m little bit afraid of that thing behind the door...")
dialogStr("Me asusta un poco esa cosa detrás de la puerta...")


dialogId("bank-m-ocicka", "font_small", "Why does it have three eyes?")
dialogStr("¿Porqué tiene tres ojos?")


dialogId("bank-v-pomoc", "font_big", "Stop what you’re doing down there and come help me!")
dialogStr("¡Detén lo que estás haciendo ahí abajo y ven a ayudarme!")


dialogId("bank-m-organismy", "font_small", "I would never have thought that we’d find so many living things inside a UFO...")
dialogStr("Nunca hubiera pensado que encontraríamos tantas cosas vivas en un OVNI...")


dialogId("bank-v-potvory", "font_big", "There are an incredible number of different creatures here!")
dialogStr("¡Hay un número increíble de criaturas distintas aquí!")


dialogId("bank-v-mnozeni", "font_big", "My goodness, look at those things reproduce!")
dialogStr("Por la bondad divina, ¡Mira como se reproducen esas cosas!")


dialogId("bank-m-nesetkala", "font_small", "I’ve never seen this kind of organism before.")
dialogStr("Nunca había visto esta clase de organismo antes.")


dialogId("bank-m-kouka", "font_small", "Help! It’s looking at me!")
dialogStr("¡Ayuda! ¡Me está mirando!")


dialogId("bank-m-fuj", "font_small", "Yuck.")
dialogStr("¡Wuack!.")


dialogId("bank-m-nervozni", "font_small", "That hand gives me the creeps...")
dialogStr("Esa mano me da escalofríos...")


dialogId("bank-m-zkumavka", "font_small", "There’s a strange odor coming from this test-tube...")
dialogStr("Hay un extraño olor que sale de ese tubo de ensayo...")


dialogId("bank-m-hlavakolem", "font_small", "All of this is making my head spin...")
dialogStr("Todo esto hace que me de vueltas la cabeza...")


dialogId("bank-v-neproplavu1", "font_big", "I can’t swim through here. We’re going to have to push this aside.")
dialogStr("No puedo nadar por aquí. Vamos a tener que empujar eso a un lado.")


dialogId("bank-v-neproplavu2", "font_big", "I can’t swim through here. We’re going to have to push this down.")
dialogStr("No puedo nadar por aquí. Vamos a tener que empujar esto hacia abajo.")


dialogId("bank-v-nahazet", "font_big", "We’re going to need to throw on a lot more of these things.")
dialogStr("Vamos a tener que tirar mucho más de esas cosas.")


dialogId("bank-v-jeste", "font_big", "More.")
dialogStr("Más.")


dialogId("bank-m-prohlednout", "font_small", "We have to look everything here over very carefully.")
dialogStr("Tenemos que mirar todo lo que hay aquí muy cuidadosamente.")


dialogId("bank-v-vypad1", "font_big", "I’d rather get out of here.")
dialogStr("Preferiría irme de aquí.")


dialogId("bank-v-vypad2", "font_big", "You know, I’d really rather get out of here.")
dialogStr("Tu sabes, realmente preferiría irme de aquí.")


dialogId("bank-v-flaska", "font_big", "The odor from this bottle is making me sick.")
dialogStr("El olor de esta botella me está enfermando.")


dialogId("bank-m-rozbila", "font_small", "Ooops, it broke...")
dialogStr("Oh, se rompió...")


dialogId("bank-m-tvorove", "font_small", "I think that some of these creatures here are a result of genetic engineering.")
dialogStr("Creo que algunas de esas criaturas son el resultado de la ingeniería genética.")


dialogId("bank-m-prehnal1", "font_small", "This is just too much!")
dialogStr("¡Esto es demasiado!")


dialogId("bank-m-prehnal2", "font_small", "How morbid!")
dialogStr("¡Qué morboso!")


dialogId("bank-m-mrtvolka", "font_small", "This corpse looks familiar to me.")
dialogStr("Este cadáver me parece familiar.")
